@@ -23,7 +23,7 @@ else:
 
 # teal = (0, 100 / 255, 140 / 255)
 teal = "teal"
-colors = [teal, "#C875C4", "#E50000", "blue", "purple", "orange"]
+colors = ["teal", "blue", "red", "blue", "purple", "orange"]
 # colors = np.random.permutation(colors)
 plt.rcParams["axes.prop_cycle"] = plt.cycler(color=colors)
 
